==> bibledit-0.9.tar.gz: bibledit-0.9/src/dialogimportsfm.h <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGIMPORT_SFM_H
#define INCLUDED_DIALOGIMPORT_SFM_H

#include <gtk/gtk.h>
#include "usfm.h"


class ImportSfmDialog
{
public:
  ImportSfmDialog (const string & project, Usfm * usfm);
  virtual ~ImportSfmDialog ();
  virtual int run ();
protected:
  GtkWidget *importsfmdialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *notebook;
  GtkWidget *vbox4;
  GtkWidget *label13;
  GtkWidget *label1;
  GtkWidget *vbox2;
  GtkWidget *label6;
  GtkWidget *select_directory_button;
  GtkWidget *alignment1;
  GtkWidget *hbox2;
  GtkWidget *image1;
  GtkWidget *label8;
  GtkWidget *number_of_files_label;
  GtkWidget *label4;
  GtkWidget *scrolledwindow1;
  GtkWidget *viewport1;
  GtkWidget *vbox3;
  GtkWidget *label10;
  GtkWidget *list_of_files_label;
  GtkWidget *label11;
  GtkWidget *label2;
  GtkWidget *scrolledwindow2;
  GtkWidget *viewport2;
  GtkWidget *summary1label;
  GtkWidget *label16;
  GtkWidget *vbox5;
  GtkWidget *label18;
  GtkWidget *label15;
  GtkWidget *vbox6;
  GtkWidget *label19;
  GtkWidget *label14;
  GtkWidget *vbox7;
  GtkWidget *label21;
  GtkWidget *label20;
  GtkWidget *vbox8;
  GtkWidget *label23;
  GtkWidget *label22;
  GtkWidget *hbox1;
  GtkWidget *backbutton;
  GtkWidget *forwardbutton;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton;
  GtkWidget *applybutton;
private:
  string myproject;
  Usfm * myusfm;
  virtual string pick_newest_filename (const vector < string > &filenames);
  virtual void set_gui ();
  virtual void select_directory_page ();
  virtual void list_all_files_page ();
  virtual void summary_per_book_page ();
  virtual void unicode_page ();
  virtual void connect_sfms_page ();
  string directory;
  vector < string > sfm_files;
  static void importsfmdialog_on_backbutton_clicked (GtkButton * button, gpointer user_data);
  virtual void on_backbutton_clicked ();
  static void importsfmdialog_on_forwardbutton_clicked (GtkButton * button, gpointer user_data);
  virtual void on_forwardbutton_clicked ();
  static void importsfmdialog_on_applybutton_clicked (GtkButton * button, gpointer user_data);
  static void importsfmdialog_on_select_directory_button_clicked (GtkButton * button, gpointer user_data);
  virtual void on_select_directory_button_clicked ();
  virtual void on_apply ();
};


#endif

==> bibledit-1.4.tar.gz: bibledit-1.4/src/dialogimportsfm.h <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGIMPORT_SFM_H
#define INCLUDED_DIALOGIMPORT_SFM_H


#include <gtk/gtk.h>
#include "usfm.h"
#include "configuration.h"
#include "session.h"


class ImportSfmDialog
{
public:
  ImportSfmDialog (Configuration * configuration, Session * session);
  virtual ~ImportSfmDialog ();
  virtual int run ();
protected:
  GtkWidget *importsfmdialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *notebook;
  GtkWidget *vbox4;
  GtkWidget *label13;
  GtkWidget *label1;
  GtkWidget *vbox2;
  GtkWidget *label6;
  GtkWidget *select_directory_button;
  GtkWidget *alignment1;
  GtkWidget *hbox2;
  GtkWidget *image1;
  GtkWidget *label8;
  GtkWidget *number_of_files_label;
  GtkWidget *label4;
  GtkWidget *scrolledwindow1;
  GtkWidget *viewport1;
  GtkWidget *vbox3;
  GtkWidget *label10;
  GtkWidget *list_of_files_label;
  GtkWidget *label11;
  GtkWidget *label2;
  GtkWidget *scrolledwindow2;
  GtkWidget *viewport2;
  GtkWidget *summary1label;
  GtkWidget *label16;
  GtkWidget *vbox5;
  GtkWidget *label18;
  GtkWidget *label15;
  GtkWidget *vbox6;
  GtkWidget *label19;
  GtkWidget *label14;
  GtkWidget *vbox7;
  GtkWidget *hbox3;
  GtkWidget *change_selection_button;
  GtkWidget *alignment2;
  GtkWidget *hbox4;
  GtkWidget *image2;
  GtkWidget *label25;
  GtkWidget *label20;
  GtkWidget *vbox8;
  GtkWidget *label23;
  GtkWidget *label22;
  GtkWidget *hbox1;
  GtkWidget *backbutton;
  GtkWidget *forwardbutton;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton;
  GtkWidget *applybutton;
private:
  Configuration * myconfiguration;
  Session * mysession;
  virtual ustring pick_newest_filename (const vector <ustring> &filenames);
  virtual void set_gui ();
  virtual void select_directory_page ();
  virtual void list_all_files_page ();
  virtual void summary_per_book_page ();
  virtual void unicode_page ();
  ustring directory;
  vector <ustring> sfm_files;
  vector <ustring> selectable_books;
  set <ustring> selected_books;
  static void importsfmdialog_on_backbutton_clicked (GtkButton * button, gpointer user_data);
  virtual void on_backbutton_clicked ();
  static void on_change_selection_button_clicked (GtkButton *button, gpointer user_data);
  virtual void on_change_selection ();
  static void importsfmdialog_on_forwardbutton_clicked (GtkButton * button, gpointer user_data);
  virtual void on_forwardbutton_clicked ();
  static void importsfmdialog_on_applybutton_clicked (GtkButton * button, gpointer user_data);
  static void importsfmdialog_on_select_directory_button_clicked (GtkButton * button, gpointer user_data);
  virtual void on_select_directory_button_clicked ();
  virtual void on_apply ();
};


#endif
